@@ -47,7 +47,7 @@ def _get_figure_and_axis():
 
 def _set_ticks(xmin, xmax, ymin, ymax):
 
-    xticks = list(np.arange(xmin + 1, xmax, n_step))
+    xticks = list(np.arange(xmin + 1, xmax, 1))
     if len(xticks) > 10:
         if xmin % 2 == 0:
             xmin = xmin + 1
@@ -63,7 +63,7 @@ def _set_ticks(xmin, xmax, ymin, ymax):
         xticks.remove(0)
     plt.xticks(xticks, fontsize=16)
 
-    yticks = list(np.arange(ymin + 1, ymax, n_step))
+    yticks = list(np.arange(ymin + 1, ymax, 1))
     if len(yticks) > 10:
         if ymin % 2 == 0:
             ymin = ymin + 1
